# Hierarchy Chart Streamlit Component

Hierarchy charts made easy.<br>
Explore to your heart's content with the code. For me metric trees became easy.

## References

This project is based on:
* [Gabriel Tem Pass' vue template guide](https://github.com/gabrieltempass/streamlit-component-vue-vite-template)
* [Primevue OrganizationChart](https://primevue.org/organizationchart)
* [Niklas von Hertzen's html2canvas ](https://html2canvas.hertzen.com)
